@@ -216,42 +216,42 @@ def get_cluster_endpoint(host):
     """
     Utility function to generate the get run endpoint given the host.
     """
-    return f"https://{host}/api/2.2/clusters/get"
+    return f"https://{host}/api/2.1/clusters/get"
 
 
 def start_cluster_endpoint(host):
     """
     Utility function to generate the get run endpoint given the host.
     """
-    return f"https://{host}/api/2.2/clusters/start"
+    return f"https://{host}/api/2.1/clusters/start"
 
 
 def restart_cluster_endpoint(host):
     """
     Utility function to generate the get run endpoint given the host.
     """
-    return f"https://{host}/api/2.2/clusters/restart"
+    return f"https://{host}/api/2.1/clusters/restart"
 
 
 def terminate_cluster_endpoint(host):
     """
     Utility function to generate the get run endpoint given the host.
     """
-    return f"https://{host}/api/2.2/clusters/delete"
+    return f"https://{host}/api/2.1/clusters/delete"
 
 
 def install_endpoint(host):
     """
     Utility function to generate the install endpoint given the host.
     """
-    return f"https://{host}/api/2.2/libraries/install"
+    return f"https://{host}/api/2.0/libraries/install"
 
 
 def uninstall_endpoint(host):
     """
     Utility function to generate the uninstall endpoint given the host.
     """
-    return f"https://{host}/api/2.2/libraries/uninstall"
+    return f"https://{host}/api/2.0/libraries/uninstall"
 
 
 def list_jobs_endpoint(host):
@@ -265,19 +265,19 @@ def list_pipelines_endpoint(host):
     """
     Utility function to generate the list jobs endpoint given the host
     """
-    return f"https://{host}/api/2.2/pipelines"
+    return f"https://{host}/api/2.0/pipelines"
 
 
 def list_spark_versions_endpoint(host):
     """Utility function to generate the list spark versions endpoint given the host"""
-    return f"https://{host}/api/2.2/clusters/spark-versions"
+    return f"https://{host}/api/2.1/clusters/spark-versions"
 
 
 def permissions_endpoint(host, job_id):
     """
     Utility function to generate the permissions endpoint given the host
     """
-    return f"https://{host}/api/2.2/permissions/jobs/{job_id}"
+    return f"https://{host}/api/2.0/permissions/jobs/{job_id}"
 
 
 def create_valid_response_mock(content):
@@ -289,7 +289,7 @@ def create_valid_response_mock(content):
 
 def sql_statements_endpoint(host):
     """Utility function to generate the sql statements endpoint given the host."""
-    return f"https://{host}/api/2.2/sql/statements"
+    return f"https://{host}/api/2.0/sql/statements"
 
 
 def create_successful_response_mock(content):
@@ -1226,6 +1226,31 @@ class TestDatabricksHook:
             timeout=self.hook.timeout_seconds,
         )
 
+    @mock.patch("airflow.providers.databricks.hooks.databricks.send_sql_hook_lineage")
+    @mock.patch("airflow.providers.databricks.hooks.databricks_base.requests")
+    def test_post_sql_statement_hook_lineage(self, mock_requests, mock_send_lineage):
+        mock_requests.post.return_value.json.return_value = {
+            "statement_id": "01f00ed2-04e2-15bd-a944-a8ae011dac69"
+        }
+        json_payload = {
+            "statement": "select * from test.test;",
+            "warehouse_id": WAREHOUSE_ID,
+            "catalog": "some_catalog",
+            "schema": "some_schema",
+            "parameters": {"a": 1},
+            "wait_timeout": "0s",
+        }
+        self.hook.post_sql_statement(json_payload)
+
+        mock_send_lineage.assert_called_once()
+        call_kw = mock_send_lineage.call_args.kwargs
+        assert call_kw["context"] is self.hook
+        assert call_kw["sql"] == "select * from test.test;"
+        assert call_kw["job_id"] == "01f00ed2-04e2-15bd-a944-a8ae011dac69"
+        assert call_kw["sql_parameters"] == {"a": 1}
+        assert call_kw["default_db"] == "some_catalog"
+        assert call_kw["default_schema"] == "some_schema"
+
     @mock.patch("airflow.providers.databricks.hooks.databricks_base.requests")
     def test_get_sql_statement_state(self, mock_requests):
         mock_requests.codes.ok = 200
@@ -1302,7 +1327,7 @@ class TestDatabricksHook:
         self.hook.update_job_permission(1, ACCESS_CONTROL_DICT)
 
         mock_requests.patch.assert_called_once_with(
-            f"https://{HOST}/api/2.2/permissions/jobs/1",
+            f"https://{HOST}/api/2.0/permissions/jobs/1",
             json=utils.normalise_json_content(ACCESS_CONTROL_DICT),
             params=None,
             auth=HTTPBasicAuth(LOGIN, PASSWORD),
@@ -1310,6 +1335,18 @@ class TestDatabricksHook:
             timeout=self.hook.timeout_seconds,
         )
 
+    def test_openlineage_methods(self):
+        from airflow.providers.openlineage.sqlparser import DatabaseInfo
+
+        db_info = self.hook.get_openlineage_database_info(None)
+        assert isinstance(db_info, DatabaseInfo)
+        assert db_info.scheme == "databricks"
+        assert db_info.authority == HOST
+        assert db_info.is_information_schema_cross_db is True
+
+        assert self.hook.get_openlineage_database_dialect(None) == "databricks"
+        assert self.hook.get_openlineage_default_schema() == "default"
+
 
 @pytest.mark.db_test
 class TestDatabricksHookToken:
@@ -2191,7 +2228,7 @@ class TestDatabricksHookSpToken:
         run_id = self.hook.submit_run(data)
 
         ad_call_args = mock_requests.method_calls[0]
-        assert ad_call_args[1][0] == OIDC_TOKEN_SERVICE_URL.format(HOST)
+        assert ad_call_args[1][0] == OIDC_TOKEN_SERVICE_URL.format(f"https://{HOST}")
         assert ad_call_args[2]["data"] == "grant_type=client_credentials&scope=all-apis"
 
         assert run_id == "1"
